@@ -227,7 +227,8 @@ PinyinEditor::commit (const gchar *str)
 void
 PinyinEditor::updatePreeditText ()
 {
-    if (DISPLAY_STYLE_COMPACT == m_config.displayStyle ())
+    if (DISPLAY_STYLE_COMPACT == m_config.displayStyle () ||
+        DISPLAY_STYLE_COMPATIBILITY == m_config.displayStyle ())
         return;
 
     guint num = 0;
@@ -241,6 +242,12 @@ PinyinEditor::updatePreeditText ()
 
     m_buffer.clear ();
 
+    /* for Legacy mode */
+    if (m_config.sortOption () & SORT_WITHOUT_SENTENCE_CANDIDATE) {
+        hidePreeditText ();
+        return;
+    }
+
     /* probe nbest match candidate */
     lookup_candidate_type_t type;
     lookup_candidate_t * candidate = NULL;
